@@ -3,7 +3,7 @@
 # System
 import time, os
 from abc import abstractmethod
-from typing import Optional, List, Tuple, Callable
+from typing import Optional, List, Tuple, Callable, Union
 
 # Pip
 from selenium_firefox import Firefox
@@ -57,12 +57,14 @@ class SeleniumAccount:
             default_find_func_timeout=default_find_func_timeout
         )
 
+        self.current_user_id = None
+
         try:
             self.__internal_id = cookies_folder_path.strip(os.path.sep).split(os.path.sep)[-1]
         except:
             self.__internal_id = cookies_folder_path or self.browser.cookies_folder_path
 
-        self.browser.get(self.home_url)
+        self.get(self.home_url)
 
         try:
             self.did_log_in_at_init = self.login_via_cookies(
@@ -75,7 +77,8 @@ class SeleniumAccount:
             self.print(e)
             self.did_log_in_at_init = False
 
-        self.current_user_id = self.__get_current_user_id() if self.did_log_in_at_init else None
+        if self.did_log_in_at_init:
+            self.current_user_id = self._get_current_user_id()
 
 
     # ------------------------------------------------------- Abstract methods ------------------------------------------------------- #
@@ -84,10 +87,6 @@ class SeleniumAccount:
     def _home_url(self) -> str:
         pass
 
-    @abstractmethod
-    def _is_logged_in(self) -> bool:
-        pass
-
     @abstractmethod
     def _get_current_user_id(self) -> Optional[str]:
         pass
@@ -101,7 +100,7 @@ class SeleniumAccount:
 
     @property
     def current_profile_url(self) -> Optional[str]:
-        return self.profile_url()
+        return self.profile_url(self.current_user_id)
 
     @property
     def home_url(self) -> str:
@@ -109,23 +108,21 @@ class SeleniumAccount:
 
     @property
     def is_logged_in(self) -> bool:
-        return self._is_logged_in()
+        self.current_user_id = self.current_user_id or self._get_current_user_id()
+
+        return self.current_user_id is not None or self._is_logged_in()
 
     @property
     def domain(self) -> str:
-        if hasattr(self, '__domain'):
-            return self.__domain
-
-        self.__domain = tldextract.extract(self.home_url).domain
+        if not hasattr(self, '__domain'):
+            self.__domain = tldextract.extract(self.home_url).domain
 
         return self.__domain
 
     @property
     def page_name(self) -> str:
-        if hasattr(self, '__page_name'):
-            return self.__page_name
-
-        self.__page_name = self.domain.lower().title()
+        if not hasattr(self, '__page_name'):
+            self.__page_name = self.domain.lower().title()
 
         return self.__page_name
 
@@ -134,9 +131,9 @@ class SeleniumAccount:
 
     def profile_url(
         self,
-        profile_id: Optional[Union[str, int]]
+        profile_id: Union[str, int]
     ) -> Optional[str]:
-        return self._profile_url_format.format(profile_id) if profile_id else None
+        return self._profile_url_format().format(profile_id) if profile_id else None
 
     def get_profile(
         self,
@@ -147,7 +144,7 @@ class SeleniumAccount:
 
             return False
 
-        self.get(profile_url(profile_id))
+        self.get(self.profile_url(profile_id))
 
         return True
 
@@ -177,7 +174,7 @@ class SeleniumAccount:
                         timeout=login_prompt_timeout_seconds
                     )
 
-                    return self.login_via_cookies(promt_user_input_login=False, save_cookies=save_cookies)
+                    return self.login_via_cookies(prompt_user_input_login=False, save_cookies=save_cookies)
                 except Exception as e:
                     self.print(e)
 
@@ -187,7 +184,7 @@ class SeleniumAccount:
 
         self.print('Successfully logged in. Saving cookies.')
         time.sleep(0.5)
-        self.browser.get(self.home_url)
+        self.get(self.home_url)
         time.sleep(0.5)
         self.save_cookies()
 
@@ -199,6 +196,9 @@ class SeleniumAccount:
     def save_cookies(self) -> None:
         self.browser.save_cookies()
 
+    def get(self, url: str) -> bool:
+        return self.browser.get(url)
+
     def quit(self) -> None:
         try:
             self.browser.driver.quit()
@@ -208,6 +208,9 @@ class SeleniumAccount:
 
     # ------------------------------------------------------- Private methods -------------------------------------------------------- #
 
+    def _is_logged_in(self) -> bool:
+        return False
+
     @signal_timeoutable(name='login_prompt_callback')
     def __call_login_prompt_callback(
         self,
